stravalib.util.limiter.XRateLimitRule
=====================================

.. currentmodule:: stravalib.util.limiter

.. autoclass:: XRateLimitRule


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~XRateLimitRule.__init__





   .. rubric:: Attributes

   .. autosummary::

      ~XRateLimitRule.limit_timeout
